<?php
class CalendarWidget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array( 
			'classname' => 'calendar-widget',
			'description' => 'GemConnect Calendar Widget',
		);
		parent::__construct( 'my_widget', 'GemConnect Calendar Widget', $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		if (array_key_exists('gemconnect_site_url', $instance) && $instance['gemconnect_site_url']) {
			$site_id = json_decode(file_get_contents('http://gemconnect.co.uk/api/gembookings/get_site_id_from_url/?site_url=' . $instance['gemconnect_site_url']));
			$events_array = json_decode(file_get_contents('http://gemconnect.co.uk/api/gembookings/get_site_events/?site_id=' . $site_id));
			
			var_dump($events_array);
		}
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		if ( isset( $instance[ 'gemconnect_site_url' ] ) ) {
                $gemconnect_site_url = $instance[ 'gemconnect_site_url' ];
            }
            else {
                $gemconnect_site_url = __( 'GemConnect Site URL', 'gemconnect_site_url' );
            }

            // Widget admin form
            ?>
            <p>
                <label for="<?php echo $this->get_field_id( 'gemconnect_site_url' ); ?>"><?php _e( 'GemConnect Site URL:' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'gemconnect_site_url' ); ?>" name="<?php echo $this->get_field_name( 'gemconnect_site_url' ); ?>" type="text" value="<?php echo esc_attr( $gemconnect_site_url ); ?>" />
            </p>
            <?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
        $instance['gemconnect_site_url'] = ( ! empty( $new_instance['gemconnect_site_url'] ) ) ? strip_tags( $new_instance['gemconnect_site_url'] ) : '';
        return $instance;
	}
}

add_action( 'widgets_init', function(){
	register_widget( 'CalendarWidget' );
});